Service Provider (pynetdicom.dimse)¶
The DIMSE Service Provider provides methods for sending and receiving messages to and from a peer AE.
DIMSEServiceProvider(dul[, dimse_timeout, …]) |
The DIMSE service provider. |
pynetdicom.dimse)¶The DIMSE Service Provider provides methods for sending and receiving messages to and from a peer AE.
DIMSEServiceProvider(dul[, dimse_timeout, …]) |
The DIMSE service provider. |