A-ASSOCIATE-RQ PDU¶
An A-ASSOCIATE-RQ PDU is made of a sequence of mandatory fields followed by a variable length field that must contain one Application Context item, one or more Presentation Context items and one User Information item. Sub-items shall exist for the Presentation Context and User Information items.
PDU¶
A_ASSOCIATE_RQ() |
An A-ASSOCIATE-RQ PDU. |
Variable Items¶
ApplicationContextItem() |
An Application Context Item. |
PresentationContextItemRQ() |
A Presentation Context (RQ) Item. |
UserInformationItem() |
A User Information Item. |
Presentation Context Sub-items¶
AbstractSyntaxSubItem() |
An Abstract Syntax Sub-item. |
TransferSyntaxSubItem() |
A Transfer Syntax Sub-item. |
User Information Sub-items¶
MaximumLengthSubItem() |
A Maximum Length Sub-item. |
ImplementationClassUIDSubItem() |
An Implementation Class UID Sub-item. |
ImplementationVersionNameSubItem() |
An Implementation Version Name Sub-item. |
SCP_SCU_RoleSelectionSubItem() |
An SCP/SCU Role Selection Sub-item. |
AsynchronousOperationsWindowSubItem() |
An Asynchronous Operations Window Sub-item. |
UserIdentitySubItemRQ() |
A User Identity (RQ) Sub-item. |
SOPClassExtendedNegotiationSubItem() |
A SOP Class Extended Negotiation Sub-item. |
SOPClassCommonExtendedNegotiationSubItem() |
A SOP Class Common Extended Negotiation Sub-item. |