A-ASSOCIATE¶
The establishment of an association between two Application Entities shall be performed through ACSE A-ASSOCIATE request, indication, response and confirmation primitives.
A_ASSOCIATE() |
An A-ASSOCIATE primitive. |
The A-ASSOCIATE service makes use of one or more of the following User Information primitives:
MaximumLengthNotification() |
A representation of a Maximum Length Negotiation primitive. |
ImplementationClassUIDNotification() |
A representation of a Implementation Class UID Notification primitive. |
ImplementationVersionNameNotification() |
A representation of a Implementation Version Name Notification primitive. |
AsynchronousOperationsWindowNegotiation() |
A representation of the Asynchronous Operations Window Negotiation primitive. |
SCP_SCU_RoleSelectionNegotiation() |
A representation of the SCP/SCU Role Selection Negotiation primitive. |
SOPClassExtendedNegotiation() |
A representation of the SOP Class Extended Negotiation primitive. |
SOPClassCommonExtendedNegotiation() |
A representation of the SOP Class Common Extended Negotiation primitive. |
UserIdentityNegotiation() |
Representation of the User Identity Negotiation primitive. |